@@ -209,6 +209,7 @@ from .._impl import (
     scout_compute_api_NumericHistogramBucketWidthAndOffset as NumericHistogramBucketWidthAndOffset,
     scout_compute_api_NumericHistogramNode as NumericHistogramNode,
     scout_compute_api_NumericHistogramPlot as NumericHistogramPlot,
+    scout_compute_api_NumericOutputField as NumericOutputField,
     scout_compute_api_NumericPlot as NumericPlot,
     scout_compute_api_NumericPoint as NumericPoint,
     scout_compute_api_NumericResampleSeries as NumericResampleSeries,
@@ -551,6 +552,7 @@ __all__ = [
     'NumericHistogramBucketWidthAndOffset',
     'NumericHistogramNode',
     'NumericHistogramPlot',
+    'NumericOutputField',
     'NumericPlot',
     'NumericPoint',
     'NumericResampleSeries',
